Summary:       Fast, high-quality sample rate conversion library
Name:          zita-resampler
Version:       1.3.0
Release:       7%{?dist}
License:       GPLv3+
Group:         System Environment/Libraries
URL:           http://kokkinizita.linuxaudio.org/linuxaudio/zita-resampler/resampler.html
Source0:       http://kokkinizita.linuxaudio.org/linuxaudio/downloads/zita-resampler-%{version}.tar.bz2
BuildRequires: libsndfile-devel

%description
zita-resampler is a C++ library for resampling audio signals. It is
designed to be used within a real-time processing context, to be fast,
and to provide high-quality sample rate conversion.

The library operates on signals represented in single-precision
floating point format. For multichannel operation both the input and
output signals are assumed to be stored as interleaved samples.

The API allows a trade-off between quality and CPU load. For the
latter a range of approximately 1:6 is available. Even at the highest
quality setting zita-resampler will be faster than most similar
libraries, e.g. libsamplerate.

%package  devel
Summary:       Development libraries and headers for %{name}
Group:         Development/Libraries
Requires:      %{name} = %{version}-%{release}

%description devel
This package contains the headers and development libraries for %{name}.

%prep
%setup -q

# To make sure to have the correct Fedora specific flags:
sed -i -e 's|-O2|%{optflags} -I../libs|' -e 's|ldconfig||' -e 's|-march=native||' libs/Makefile
sed -i -e 's|-O3|%{optflags} -I../libs|' -e 's|-march=native||' apps/Makefile

%build
export LDFLAGS="-L../libs"
make %{?_smp_mflags} -C libs
# In order to build apps, we need to create the symlink
# Note that this is originally done at "make install" stage
ln -sf libzita-resampler.so.%{version} libs/libzita-resampler.so

make %{?_smp_mflags} -C apps

%install
rm -rf %{buildroot}
make PREFIX=%{buildroot}%{_prefix} LIBDIR=%{_lib} -C libs install
make MANDIR=%{buildroot}%{_mandir}/man1 PREFIX=%{buildroot}%{_prefix} LIBDIR=%{_lib} -C apps install
/sbin/ldconfig -n %{buildroot}/%{_libdir}
chmod 755 %{buildroot}/%{_libdir}/lib%{name}.so.%{version}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc AUTHORS COPYING
%{_libdir}/lib%{name}.so.*
%{_bindir}/zresample
%{_bindir}/zretune
%{_mandir}/man1/zresample.1.*
%{_mandir}/man1/zretune.1.*

%files devel
%doc docs/*
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so

%changelog
* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.3.0-6
- Rebuilt for GCC 5 C++11 ABI change

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Oct 27 2012 Brendan Jones <brendan.jones.it@gmail.com> 1.3.0-1
- New upstream release

* Fri Oct 26 2012 Dan Horák <dan[at]danny.cz> - 1.1.0-3
- can't use -march=native in build system

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 02 2012 Brendan Jones <brendan.jones.it@gmail.com> 1.1.0-1
- Update to 1.1.0
- Update URL, bring SPEC file up to date to current version

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Aug 04 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.1.1-3
- Fix header includes

* Sat Apr 10 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.1.1-2
- Fix libdir on non-*x86* systems

* Sat Apr 10 2010 Orcan Ogetbil <oget [DOT] fedora [AT] gmail [DOT] com> - 0.1.1-1
- Update to 0.1.1
- Prepare package for Fedora (specfile from PlanetCCRMA)

* Wed Oct 29 2008 Fernando Lopez-Lezcano <nando@ccrma.stanford.edu> 0.1.0-1
- initial release
